@@ -97,7 +97,7 @@ public:
 class IceTransport::Impl
 {
 public:
-    Impl(const char* name);
+    Impl(std::string_view name);
     ~Impl();
 
     void initIceInstance(const IceTransportOptions& options);
@@ -153,7 +153,7 @@ public:
     std::condition_variable_any iceCV_ {};
 
     std::string sessionName_ {};
-    std::unique_ptr<pj_pool_t, std::function<void(pj_pool_t*)>> pool_ {};
+    std::unique_ptr<pj_pool_t, decltype(&pj_pool_release)> pool_ {nullptr, pj_pool_release};
     bool isTcp_ {false};
     bool upnpEnabled_ {false};
     IceTransportCompleteCb on_initdone_cb_ {};
@@ -236,6 +236,9 @@ public:
     {
         for (auto& c : peerChannels_)
             c.stop();
+        std::lock_guard<std::mutex> lk(sendDataMutex_);
+        destroying_ = true;
+        waitDataCv_.notify_all();
     }
 };
 
@@ -325,12 +328,10 @@ add_turn_server(pj_pool_t& pool, pj_ice_strans_cfg& cfg, const TurnServerInfo& i
 
 //==============================================================================
 
-IceTransport::Impl::Impl(const char* name)
+IceTransport::Impl::Impl(std::string_view name)
     : sessionName_(name)
-    , pool_(nullptr, [](pj_pool_t* pool) { pj_pool_release(pool); })
-    , thread_()
 {
-    JAMI_DBG("[ice:%p] Creating IceTransport session for \"%s\"", this, name);
+    JAMI_DEBUG("[ice:{}] Creating IceTransport session for \"{:s}\"", fmt::ptr(this), name);
 }
 
 IceTransport::Impl::~Impl()
@@ -512,9 +513,6 @@ IceTransport::Impl::initIceInstance(const IceTransportOptions& options)
     icecb.on_destroy = [](pj_ice_strans* ice_st) {
         if (auto* tr = static_cast<Impl*>(pj_ice_strans_get_user_data(ice_st))) {
             tr->cancelOperations(); // Avoid upper layer to manage this ; Stop read operations
-            std::lock_guard lk(tr->sendDataMutex_);
-            tr->destroying_ = true;
-            tr->waitDataCv_.notify_all(); // Stop write operations
         } else {
             JAMI_WARN("null IceTransport");
         }
@@ -559,7 +557,7 @@ IceTransport::Impl::initIceInstance(const IceTransportOptions& options)
 bool
 IceTransport::Impl::_isInitialized() const
 {
-    if (auto icest = icest_) {
+    if (auto *icest = icest_) {
         auto state = pj_ice_strans_get_state(icest);
         return state >= PJ_ICE_STRANS_STATE_SESS_READY and state != PJ_ICE_STRANS_STATE_FAILED;
     }
@@ -569,7 +567,7 @@ IceTransport::Impl::_isInitialized() const
 bool
 IceTransport::Impl::_isStarted() const
 {
-    if (auto icest = icest_) {
+    if (auto *icest = icest_) {
         auto state = pj_ice_strans_get_state(icest);
         return state >= PJ_ICE_STRANS_STATE_NEGO and state != PJ_ICE_STRANS_STATE_FAILED;
     }
@@ -579,7 +577,7 @@ IceTransport::Impl::_isStarted() const
 bool
 IceTransport::Impl::_isRunning() const
 {
-    if (auto icest = icest_) {
+    if (auto *icest = icest_) {
         auto state = pj_ice_strans_get_state(icest);
         return state >= PJ_ICE_STRANS_STATE_RUNNING and state != PJ_ICE_STRANS_STATE_FAILED;
     }
@@ -589,7 +587,7 @@ IceTransport::Impl::_isRunning() const
 bool
 IceTransport::Impl::_isFailed() const
 {
-    if (auto icest = icest_)
+    if (auto *icest = icest_)
         return pj_ice_strans_get_state(icest) == PJ_ICE_STRANS_STATE_FAILED;
     return false;
 }
@@ -1142,7 +1140,7 @@ IceTransport::Impl::_waitForInitialization(std::chrono::milliseconds timeout)
 
 //==============================================================================
 
-IceTransport::IceTransport(const char* name)
+IceTransport::IceTransport(std::string_view name)
     : pimpl_ {std::make_unique<Impl>(name)}
 {}
 
@@ -1155,7 +1153,6 @@ void
 IceTransport::initIceInstance(const IceTransportOptions& options)
 {
     pimpl_->initIceInstance(options);
-
     jami_tracepoint(ice_transport_context, reinterpret_cast<uint64_t>(this));
 }
 
@@ -1344,7 +1341,6 @@ IceTransport::startIce(const SDP& sdp)
 void
 IceTransport::cancelOperations()
 {
-    isCancelled_ = true;
     pimpl_->cancelOperations();
 }
 
@@ -1716,43 +1712,6 @@ IceTransport::waitForData(unsigned compId, std::chrono::milliseconds timeout, st
     return pimpl_->peerChannels_.at(compId - 1).wait(timeout, ec);
 }
 
-std::vector<SDP>
-IceTransport::parseSDPList(const std::vector<uint8_t>& msg)
-{
-    std::vector<SDP> sdp_list;
-
-    try {
-        size_t off = 0;
-        while (off != msg.size()) {
-            msgpack::unpacked result;
-            msgpack::unpack(result, (const char*) msg.data(), msg.size(), off);
-            SDP sdp;
-            if (result.get().type == msgpack::type::POSITIVE_INTEGER) {
-                // Version 1
-                msgpack::unpack(result, (const char*) msg.data(), msg.size(), off);
-                std::tie(sdp.ufrag, sdp.pwd) = result.get().as<std::pair<std::string, std::string>>();
-                msgpack::unpack(result, (const char*) msg.data(), msg.size(), off);
-                auto comp_cnt = result.get().as<uint8_t>();
-                while (comp_cnt-- > 0) {
-                    msgpack::unpack(result, (const char*) msg.data(), msg.size(), off);
-                    auto candidates = result.get().as<std::vector<std::string>>();
-                    sdp.candidates.reserve(sdp.candidates.size() + candidates.size());
-                    sdp.candidates.insert(sdp.candidates.end(),
-                                          candidates.begin(),
-                                          candidates.end());
-                }
-            } else {
-                result.get().convert(sdp);
-            }
-            sdp_list.emplace_back(std::move(sdp));
-        }
-    } catch (const msgpack::unpack_error& e) {
-        JAMI_WARN("Error parsing sdp: %s", e.what());
-    }
-
-    return sdp_list;
-}
-
 bool
 IceTransport::isTCPEnabled()
 {
@@ -1830,7 +1789,7 @@ IceTransportFactory::IceTransportFactory()
 IceTransportFactory::~IceTransportFactory() {}
 
 std::shared_ptr<IceTransport>
-IceTransportFactory::createTransport(const char* name)
+IceTransportFactory::createTransport(std::string_view name)
 {
     try {
         return std::make_shared<IceTransport>(name);
@@ -1841,7 +1800,7 @@ IceTransportFactory::createTransport(const char* name)
 }
 
 std::unique_ptr<IceTransport>
-IceTransportFactory::createUTransport(const char* name)
+IceTransportFactory::createUTransport(std::string_view name)
 {
     try {
         return std::make_unique<IceTransport>(name);
@@ -1853,82 +1812,6 @@ IceTransportFactory::createUTransport(const char* name)
 
 //==============================================================================
 
-void
-IceSocketTransport::setOnRecv(RecvCb&& cb)
-{
-    return ice_->setOnRecv(compId_, cb);
-}
-
-bool
-IceSocketTransport::isInitiator() const
-{
-    return ice_->isInitiator();
-}
-
-void
-IceSocketTransport::shutdown()
-{
-    ice_->cancelOperations();
-}
-
-int
-IceSocketTransport::maxPayload() const
-{
-    auto ip_header_size = (ice_->getRemoteAddress(compId_).getFamily() == AF_INET)
-                              ? IPV4_HEADER_SIZE
-                              : IPV6_HEADER_SIZE;
-    return STANDARD_MTU_SIZE - ip_header_size - UDP_HEADER_SIZE;
-}
-
-int
-IceSocketTransport::waitForData(std::chrono::milliseconds timeout, std::error_code& ec) const
-{
-    if (!ice_->isRunning())
-        return -1;
-    return ice_->waitForData(compId_, timeout, ec);
-}
-
-std::size_t
-IceSocketTransport::write(const ValueType* buf, std::size_t len, std::error_code& ec)
-{
-    auto res = ice_->send(compId_, buf, len);
-    if (res < 0) {
-        ec.assign(errno, std::generic_category());
-        return 0;
-    }
-    ec.clear();
-    return res;
-}
-
-std::size_t
-IceSocketTransport::read(ValueType* buf, std::size_t len, std::error_code& ec)
-{
-    if (!ice_->isRunning())
-        return 0;
-    try {
-        auto res = reliable_ ? ice_->recvfrom(compId_, reinterpret_cast<char*>(buf), len, ec)
-                             : ice_->recv(compId_, buf, len, ec);
-        return (res < 0) ? 0 : res;
-    } catch (const std::exception& e) {
-        JAMI_ERR("IceSocketTransport::read exception: %s", e.what());
-    }
-    return 0;
-}
-
-IpAddr
-IceSocketTransport::localAddr() const
-{
-    return ice_->getLocalAddress(compId_);
-}
-
-IpAddr
-IceSocketTransport::remoteAddr() const
-{
-    return ice_->getRemoteAddress(compId_);
-}
-
-//==============================================================================
-
 void
 IceSocket::close()
 {
