@@ -28,7 +28,8 @@
 #include <json/json.h>
 #include <string_view>
 #include <opendht/thread_pool.h>
-
+#include <tuple>
+#include "swarm/swarm_manager.h"
 #ifdef ENABLE_PLUGIN
 #include "manager.h"
 #include "plugin/jamipluginmanager.h"
@@ -38,7 +39,7 @@
 namespace jami {
 
 static const char* const LAST_MODIFIED = "lastModified";
-static const auto jsonBuilder =  []{
+static const auto jsonBuilder = [] {
     Json::StreamWriterBuilder wbuilder;
     wbuilder["commentStyle"] = "None";
     wbuilder["indentation"] = "";
@@ -121,19 +122,19 @@ ConversationRequest::toMap() const
 class Conversation::Impl
 {
 public:
-    Impl(const std::weak_ptr<JamiAccount>& account,
+    Impl(const std::shared_ptr<JamiAccount>& account,
          ConversationMode mode,
          const std::string& otherMember = "")
-        : account_(account)
+        : repository_(ConversationRepository::createConversation(account, mode, otherMember))
+        , account_(account)
     {
-        repository_ = ConversationRepository::createConversation(account, mode, otherMember);
         if (!repository_) {
             throw std::logic_error("Couldn't create repository");
         }
         init();
     }
 
-    Impl(const std::weak_ptr<JamiAccount>& account, const std::string& conversationId)
+    Impl(const std::shared_ptr<JamiAccount>& account, const std::string& conversationId)
         : account_(account)
     {
         repository_ = std::make_unique<ConversationRepository>(account, conversationId);
@@ -143,7 +144,7 @@ public:
         init();
     }
 
-    Impl(const std::weak_ptr<JamiAccount>& account,
+    Impl(const std::shared_ptr<JamiAccount>& account,
          const std::string& remoteDevice,
          const std::string& conversationId)
         : account_(account)
@@ -152,10 +153,8 @@ public:
                                                                 remoteDevice,
                                                                 conversationId);
         if (!repository_) {
-            if (auto shared = account.lock()) {
-                emitSignal<libjami::ConversationSignal::OnConversationError>(
-                    shared->getAccountID(), conversationId, EFETCH, "Couldn't clone repository");
-            }
+            emitSignal<libjami::ConversationSignal::OnConversationError>(
+                account->getAccountID(), conversationId, EFETCH, "Couldn't clone repository");
             throw std::logic_error("Couldn't clone repository");
         }
         init();
@@ -170,6 +169,10 @@ public:
     void init()
     {
         if (auto shared = account_.lock()) {
+            ioContext_ = Manager::instance().ioContext();
+            fallbackTimer_ = std::make_unique<asio::steady_timer>(*ioContext_);
+            swarmManager_ = std::make_shared<SwarmManager>(NodeId(shared->currentDeviceId()));
+            swarmManager_->setMobility(shared->isMobile());
             accountId_ = shared->getAccountID();
             transferManager_ = std::make_shared<TransferManager>(shared->getAccountID(),
                                                                  repository_->id());
@@ -192,6 +195,27 @@ public:
         }
     }
 
+    const std::string& toString() const
+    {
+        if (fmtStr_.empty()) {
+            if (repository_->mode() == ConversationMode::ONE_TO_ONE) {
+                if (auto acc = account_.lock()) {
+                    auto peer = acc->getUsername();
+                    for (const auto& member : repository_->getInitialMembers()) {
+                        if (member != acc->getUsername()) {
+                            peer = member;
+                        }
+                    }
+                    fmtStr_ = fmt::format("[Conversation (1:1) {}]", peer);
+                }
+            } else {
+                fmtStr_ = fmt::format("[Conversation {}]", repository_->id());
+            }
+        }
+        return fmtStr_;
+    }
+    mutable std::string fmtStr_;
+
     /**
      * If, for whatever reason, the daemon is stopped while hosting a conference,
      * we need to announce the end of this call when restarting.
@@ -199,15 +223,20 @@ public:
      */
     std::vector<std::string> announceEndedCalls();
 
-    ~Impl() = default;
+    ~Impl()
+    {
+        try {
+            if (fallbackTimer_)
+                fallbackTimer_->cancel();
+        } catch (const std::exception& e) {
+            JAMI_ERROR("[Conversation {:s}] {:s}", toString(), e.what());
+        }
+    }
 
     std::vector<std::string> refreshActiveCalls();
     bool isAdmin() const;
     std::string repoPath() const;
 
-    // Protect against parallel commits in the repo
-    // As the index can add files to the commit we want.
-    std::mutex writeMtx_ {};
     void announce(const std::string& commitId) const
     {
         std::vector<std::string> vec;
@@ -273,11 +302,12 @@ public:
             auto device = commit.at("device");
             std::lock_guard<std::mutex> lk(activeCallsMtx_);
             auto itActive = std::find_if(activeCalls_.begin(),
-                                            activeCalls_.end(),
-                                                [&](const auto& value) {
-                                                    return value.at("id") == confId && value.at("uri") == uri
-                                                        && value.at("device") == device;
-                                                });
+                                         activeCalls_.end(),
+                                         [&](const auto& value) {
+                                             return value.at("id") == confId
+                                                    && value.at("uri") == uri
+                                                    && value.at("device") == device;
+                                         });
             if (commit.find("duration") == commit.end()) {
                 if (itActive == activeCalls_.end() && !eraseOnly) {
                     JAMI_DEBUG(
@@ -301,18 +331,16 @@ public:
                     itActive = activeCalls_.erase(itActive);
                     // Unlikely, but we must ensure that no duplicate exists
                     while (itActive != activeCalls_.end()) {
-                        itActive = std::find_if(itActive, activeCalls_.end(),
-                                                [&](const auto& value) {
-                                                    return value.at("id") == confId && value.at("uri") == uri
-                                                        && value.at("device") == device;
-                                                });
+                        itActive = std::find_if(itActive, activeCalls_.end(), [&](const auto& value) {
+                            return value.at("id") == confId && value.at("uri") == uri
+                                   && value.at("device") == device;
+                        });
                         if (itActive != activeCalls_.end()) {
                             JAMI_ERROR("Duplicate call found. (This is a bug)");
                             itActive = activeCalls_.erase(itActive);
                         }
                     }
 
-
                     if (eraseOnly) {
                         JAMI_WARNING("previous swarm:{:s} call finished detected: {:s} on device "
                                      "{:s}, account {:s}",
@@ -418,10 +446,7 @@ public:
             }
 
             if (announceMember) {
-                std::vector<std::string> members;
-                for (const auto& m : repository_->members())
-                    members.emplace_back(m.uri);
-                shared->saveMembers(convId, members);
+                shared->saveMembers(convId, repository_->memberUris("", {}));
             }
         }
     }
@@ -524,28 +549,58 @@ public:
         msgpack::pack(file, hostedCalls_);
     }
 
-    void voteUnban(const std::string& contactUri, const std::string& type, const OnDoneCb& cb);
+    void voteUnban(const std::string& contactUri, const std::string_view type, const OnDoneCb& cb);
 
-    std::string bannedType(std::string_view uri) const
+    std::vector<std::map<std::string, std::string>> getMembers(bool includeInvited,
+                                                               bool includeLeft,
+                                                               bool includeBanned) const;
+
+    std::string_view bannedType(const std::string& uri) const
     {
         auto bannedMember = fmt::format("{}/banned/members/{}.crt", repoPath(), uri);
         if (fileutils::isFile(bannedMember))
-            return "members";
+            return "members"sv;
         auto bannedAdmin = fmt::format("{}/banned/admins/{}.crt", repoPath(), uri);
         if (fileutils::isFile(bannedAdmin))
-            return "admins";
+            return "admins"sv;
         auto bannedInvited = fmt::format("{}/banned/invited/{}", repoPath(), uri);
         if (fileutils::isFile(bannedInvited))
-            return "invited";
+            return "invited"sv;
         auto bannedDevice = fmt::format("{}/banned/devices/{}.crt", repoPath(), uri);
         if (fileutils::isFile(bannedDevice))
-            return "devices";
+            return "devices"sv;
         return {};
     }
 
+    std::shared_ptr<ChannelSocket> gitSocket(const DeviceId& deviceId) const
+    {
+        auto deviceSockets = gitSocketList_.find(deviceId);
+        return (deviceSockets != gitSocketList_.end()) ? deviceSockets->second : nullptr;
+    }
+
+    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<ChannelSocket>& socket)
+    {
+        gitSocketList_[deviceId] = socket;
+    }
+    void removeGitSocket(const DeviceId& deviceId)
+    {
+        auto deviceSockets = gitSocketList_.find(deviceId);
+        if (deviceSockets != gitSocketList_.end())
+            gitSocketList_.erase(deviceSockets);
+    }
+
     std::vector<std::map<std::string, std::string>> getMembers(bool includeInvited,
-                                                               bool includeLeft, bool includeBanned) const;
+                                                               bool includeLeft) const;
+
+    std::set<std::string> checkedMembers_; // Store members we tried
+    std::function<void()> bootstrapCb_;
+#ifdef LIBJAMI_TESTABLE
+    std::function<void(std::string, BootstrapStatus)> bootstrapCbTest_;
+#endif
+
+    std::mutex writeMtx_ {};
     std::unique_ptr<ConversationRepository> repository_;
+    std::shared_ptr<SwarmManager> swarmManager_;
     std::weak_ptr<JamiAccount> account_;
     std::atomic_bool isRemoving_ {false};
     std::vector<std::map<std::string, std::string>> loadMessages(const LogOptions& options);
@@ -580,6 +635,14 @@ public:
     std::string activeCallsPath_ {};
     mutable std::mutex activeCallsMtx_ {};
     mutable std::vector<std::map<std::string, std::string>> activeCalls_ {};
+
+    GitSocketList gitSocketList_ {};
+
+    // Bootstrap
+    std::shared_ptr<asio::io_context> ioContext_;
+    std::unique_ptr<asio::steady_timer> fallbackTimer_;
+
+    bool isMobile {false};
 };
 
 bool
@@ -695,18 +758,18 @@ Conversation::Impl::loadMessages(const LogOptions& options)
     return repository_->convCommitToMap(convCommits);
 }
 
-Conversation::Conversation(const std::weak_ptr<JamiAccount>& account,
+Conversation::Conversation(const std::shared_ptr<JamiAccount>& account,
                            ConversationMode mode,
                            const std::string& otherMember)
     : pimpl_ {new Impl {account, mode, otherMember}}
 {}
 
-Conversation::Conversation(const std::weak_ptr<JamiAccount>& account,
+Conversation::Conversation(const std::shared_ptr<JamiAccount>& account,
                            const std::string& conversationId)
     : pimpl_ {new Impl {account, conversationId}}
 {}
 
-Conversation::Conversation(const std::weak_ptr<JamiAccount>& account,
+Conversation::Conversation(const std::shared_ptr<JamiAccount>& account,
                            const std::string& remoteDevice,
                            const std::string& conversationId)
     : pimpl_ {new Impl {account, remoteDevice, conversationId}}
@@ -750,7 +813,7 @@ Conversation::addMember(const std::string& contactUri, const OnDoneCb& cb)
                 [w = weak(), contactUri = std::move(contactUri), cb = std::move(cb)] {
                     if (auto sthis = w.lock()) {
                         auto members = sthis->pimpl_->repository_->members();
-                        std::string type = sthis->pimpl_->bannedType(contactUri);
+                        auto type = sthis->pimpl_->bannedType(contactUri);
                         if (type.empty()) {
                             cb(false, {});
                             return;
@@ -778,9 +841,52 @@ Conversation::addMember(const std::string& contactUri, const OnDoneCb& cb)
     });
 }
 
+std::shared_ptr<ChannelSocket>
+Conversation::gitSocket(const DeviceId& deviceId) const
+{
+    return pimpl_->gitSocket(deviceId);
+}
+
+void
+Conversation::addGitSocket(const DeviceId& deviceId, const std::shared_ptr<ChannelSocket>& socket)
+{
+    pimpl_->addGitSocket(deviceId, socket);
+}
+
+void
+Conversation::removeGitSocket(const DeviceId& deviceId)
+{
+    pimpl_->removeGitSocket(deviceId);
+}
+
+void
+Conversation::shutdownConnections()
+{
+    pimpl_->fallbackTimer_->cancel();
+    pimpl_->gitSocketList_.clear();
+    if (pimpl_->swarmManager_)
+        pimpl_->swarmManager_->shutdown();
+    pimpl_->checkedMembers_.clear();
+}
+
+void
+Conversation::connectivityChanged()
+{
+    if (pimpl_->swarmManager_)
+        pimpl_->swarmManager_->maintainBuckets();
+}
+
+bool
+Conversation::hasSwarmChannel(const std::string& deviceId)
+{
+    if (!pimpl_->swarmManager_)
+        return false;
+    return pimpl_->swarmManager_->isConnectedWith(DeviceId(deviceId));
+}
+
 void
 Conversation::Impl::voteUnban(const std::string& contactUri,
-                              const std::string& type,
+                              const std::string_view type,
                               const OnDoneCb& cb)
 {
     // Check if admin
@@ -876,7 +982,23 @@ Conversation::removeMember(const std::string& contactUri, bool isDevice, const O
                 JAMI_WARN("Vote solved for %s. %s banned",
                           contactUri.c_str(),
                           isDevice ? "Device" : "Member");
+
+                const auto nodes = sthis->pimpl_->swarmManager_->getRoutingTable().getAllNodes();
+                // Remove nodes from swarmManager
+                std::vector<NodeId> toRemove;
+                for (const auto node : nodes)
+                    if (contactUri == sthis->uriFromDevice(node.toString()))
+                        toRemove.emplace_back(node);
+                sthis->pimpl_->swarmManager_->deleteNode(toRemove);
+                // Remove git sockets with this member
+                std::vector<DeviceId> gitToRm;
+                for (const auto& [deviceId, _] : sthis->pimpl_->gitSocketList_)
+                    if (contactUri == sthis->uriFromDevice(deviceId.toString()))
+                        gitToRm.emplace_back(deviceId);
+                for (const auto& did: gitToRm)
+                    sthis->removeGitSocket(did);
             }
+
             sthis->pimpl_->announce(commits);
             lk.unlock();
             cb(!lastId.empty(), lastId);
@@ -896,6 +1018,41 @@ Conversation::memberUris(std::string_view filter, const std::set<MemberRole>& fi
     return pimpl_->repository_->memberUris(filter, filteredRoles);
 }
 
+std::vector<NodeId>
+Conversation::peersToSyncWith() const
+{
+    const auto& routingTable = pimpl_->swarmManager_->getRoutingTable();
+    const auto& nodes = routingTable.getNodes();
+    const auto& mobiles = routingTable.getMobileNodes();
+    std::vector<NodeId> s;
+    s.reserve(nodes.size() + mobiles.size());
+    s.insert(s.end(), nodes.begin(), nodes.end());
+    s.insert(s.end(), mobiles.begin(), mobiles.end());
+    for (const auto& [deviceId, _] : pimpl_->gitSocketList_)
+        if (std::find(s.cbegin(), s.cend(), deviceId) == s.cend())
+            s.emplace_back(deviceId);
+    return s;
+}
+
+bool
+Conversation::isBootstraped() const
+{
+    const auto& routingTable = pimpl_->swarmManager_->getRoutingTable();
+    return !routingTable.getNodes().empty();
+}
+
+std::string
+Conversation::uriFromDevice(const std::string& deviceId) const
+{
+    return pimpl_->repository_->uriFromDevice(deviceId);
+}
+
+void
+Conversation::monitor()
+{
+    pimpl_->swarmManager_->getRoutingTable().printRoutingTable();
+}
+
 std::string
 Conversation::join()
 {
@@ -1215,11 +1372,9 @@ Conversation::sync(const std::string& member,
     if (auto account = pimpl_->account_.lock()) {
         // For waiting request, downloadFile
         for (const auto& wr : dataTransfer()->waitingRequests()) {
-            auto path = fileutils::get_data_dir() + DIR_SEPARATOR_STR
-                        + account->getAccountID() + DIR_SEPARATOR_STR
-                        + "conversation_data" + DIR_SEPARATOR_STR
-                        + id() + DIR_SEPARATOR_STR
-                        + wr.fileId;
+            auto path = fileutils::get_data_dir() + DIR_SEPARATOR_STR + account->getAccountID()
+                        + DIR_SEPARATOR_STR + "conversation_data" + DIR_SEPARATOR_STR + id()
+                        + DIR_SEPARATOR_STR + wr.fileId;
             auto start = fileutils::size(path);
             if (start < 0)
                 start = 0;
@@ -1325,7 +1480,7 @@ Conversation::updatePreferences(const std::map<std::string, std::string>& map)
     auto itLast = prefs.find(LAST_MODIFIED);
     if (itLast != prefs.end()) {
         if (fileutils::isFile(filePath)) {
-            auto lastModified = fileutils::lastWriteTime(filePath);
+            auto lastModified = fileutils::lastWriteTimeInSeconds(filePath);
             try {
                 if (lastModified >= std::stoul(itLast->second))
                     return;
@@ -1353,7 +1508,8 @@ Conversation::preferences(bool includeLastModified) const
         msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
         oh.get().convert(preferences);
         if (includeLastModified)
-            preferences[LAST_MODIFIED] = fmt::format("{}", fileutils::lastWriteTime(filePath));
+            preferences[LAST_MODIFIED] =
+                    std::to_string(fileutils::lastWriteTimeInSeconds(filePath));
         return preferences;
     } catch (const std::exception& e) {
     }
@@ -1530,12 +1686,14 @@ Conversation::setMessageDisplayed(const std::string& uri, const std::string& int
 void
 Conversation::updateLastDisplayed(const std::map<std::string, std::string>& map)
 {
-    auto filePath = fmt::format("{}/{}", pimpl_->conversationDataPath_, ConversationMapKeys::LAST_DISPLAYED);
+    auto filePath = fmt::format("{}/{}",
+                                pimpl_->conversationDataPath_,
+                                ConversationMapKeys::LAST_DISPLAYED);
     auto prefs = map;
     auto itLast = prefs.find(LAST_MODIFIED);
     if (itLast != prefs.end()) {
         if (fileutils::isFile(filePath)) {
-            auto lastModified = fileutils::lastWriteTime(filePath);
+            auto lastModified = fileutils::lastWriteTimeInSeconds(filePath);
             try {
                 if (lastModified >= std::stoul(itLast->second))
                     return;
@@ -1546,7 +1704,7 @@ Conversation::updateLastDisplayed(const std::map<std::string, std::string>& map)
         prefs.erase(itLast);
     }
 
-    for (const auto& [uri, id]: prefs)
+    for (const auto& [uri, id] : prefs)
         setMessageDisplayed(uri, id);
 }
 
@@ -1605,17 +1763,157 @@ Conversation::displayed() const
 {
     try {
         std::map<std::string, std::string> lastDisplayed;
-        auto filePath = fmt::format("{}/{}", pimpl_->conversationDataPath_, ConversationMapKeys::LAST_DISPLAYED);
+        auto filePath = fmt::format("{}/{}",
+                                    pimpl_->conversationDataPath_,
+                                    ConversationMapKeys::LAST_DISPLAYED);
         auto file = fileutils::loadFile(filePath);
         msgpack::object_handle oh = msgpack::unpack((const char*) file.data(), file.size());
         oh.get().convert(lastDisplayed);
-        lastDisplayed[LAST_MODIFIED] = fmt::format("{}", fileutils::lastWriteTime(filePath));
+        lastDisplayed[LAST_MODIFIED] =
+                std::to_string(fileutils::lastWriteTimeInSeconds(filePath));
         return lastDisplayed;
     } catch (const std::exception& e) {
     }
     return {};
 }
 
+#ifdef LIBJAMI_TESTABLE
+void
+Conversation::onBootstrapStatus(const std::function<void(std::string, BootstrapStatus)>& cb)
+{
+    pimpl_->bootstrapCbTest_ = cb;
+}
+#endif
+
+void
+Conversation::checkBootstrapMember(const asio::error_code& ec,
+                                   std::vector<std::map<std::string, std::string>> members)
+{
+    auto acc = pimpl_->account_.lock();
+    if (ec == asio::error::operation_aborted
+        or pimpl_->swarmManager_->getRoutingTable().getNodes().size() > 0
+        or not acc)
+        return;
+    // We bootstrap the DRT with devices who already wrote in the repository.
+    // However, in a conversation, a large number of devices may just watch
+    // the conversation, but never write any message.
+    std::string uri;
+    while (!members.empty()) {
+        auto member = members.back();
+        members.pop_back();
+        auto& uri = member.at("uri");
+        if (uri != acc->getUsername()
+            && pimpl_->checkedMembers_.find(uri) == pimpl_->checkedMembers_.end())
+            break;
+    }
+    // If members is empty, we finished the fallback un-successfully
+    if (members.empty() && uri.empty()) {
+        JAMI_WARNING("{}[SwarmManager {}] Bootstrap: Fallback failed. Wait for remote connections.",
+                     pimpl_->toString(),
+                     fmt::ptr(pimpl_->swarmManager_.get()));
+#ifdef LIBJAMI_TESTABLE
+        if (pimpl_->bootstrapCbTest_)
+            pimpl_->bootstrapCbTest_(id(), BootstrapStatus::FAILED);
+#endif
+        return;
+    }
+
+    // Fallback, check devices of a member (we didn't check yet) in the conversation
+    pimpl_->checkedMembers_.emplace(uri);
+    auto devices = std::make_shared<std::vector<NodeId>>();
+    acc->forEachDevice(
+        dht::InfoHash(uri),
+        [w = weak(), devices](const std::shared_ptr<dht::crypto::PublicKey>& dev) {
+            // Test if already sent
+            if (auto sthis = w.lock()) {
+                if (!sthis->pimpl_->swarmManager_->getRoutingTable().hasKnownNode(dev->getLongId()))
+                    devices->emplace_back(dev->getLongId());
+            }
+        },
+        [w = weak(), devices, members = std::move(members), uri](bool ok) {
+            auto sthis = w.lock();
+            if (!sthis)
+                return;
+            if (ok && devices->size() != 0) {
+#ifdef LIBJAMI_TESTABLE
+                if (sthis->pimpl_->bootstrapCbTest_)
+                    sthis->pimpl_->bootstrapCbTest_(sthis->id(), BootstrapStatus::FALLBACK);
+#endif
+                JAMI_WARNING("{}[SwarmManager {}] Bootstrap: Fallback with member: {}",
+                             sthis->pimpl_->toString(),
+                             fmt::ptr(sthis->pimpl_->swarmManager_.get()),
+                             uri);
+                sthis->pimpl_->swarmManager_->setKnownNodes(*devices);
+            } else {
+                // Check next member
+                sthis->pimpl_->fallbackTimer_->expires_at(std::chrono::steady_clock::now());
+                sthis->pimpl_->fallbackTimer_->async_wait(
+                    std::bind(&Conversation::checkBootstrapMember,
+                              sthis,
+                              std::placeholders::_1,
+                              std::move(members)));
+            }
+        });
+}
+
+void
+Conversation::bootstrap(std::function<void()> onBootstraped, const std::vector<DeviceId>& knownDevices)
+{
+    if (!pimpl_ || !pimpl_->repository_ || !pimpl_->swarmManager_)
+        return;
+    // Here, we bootstrap the DRT with devices who already wrote in the conversation
+    // If this doesn't work, it will try to fallback with checkBootstrapMember
+    // If it works, the callback onConnectionChanged will be called with ok=true
+    pimpl_->bootstrapCb_ = std::move(onBootstraped);
+    std::vector<DeviceId> devices = knownDevices;
+    for (const auto& m : pimpl_->repository_->devices())
+        devices.insert(devices.end(), m.second.begin(), m.second.end());
+    JAMI_DEBUG("{}[SwarmManager {}] Bootstrap with {} devices",
+               pimpl_->toString(),
+               fmt::ptr(pimpl_->swarmManager_.get()),
+               devices.size());
+    // set callback
+    pimpl_->swarmManager_->onConnectionChanged([w = weak()](bool ok) {
+        // This will call methods from accounts, so trigger on another thread.
+        dht::ThreadPool::io().run([w, ok] {
+            auto sthis = w.lock();
+            if (!sthis)
+                return;
+            if (ok) {
+                // Bootstrap succeeded!
+                sthis->pimpl_->checkedMembers_.clear();
+                if (sthis->pimpl_->bootstrapCb_)
+                    sthis->pimpl_->bootstrapCb_();
+#ifdef LIBJAMI_TESTABLE
+                if (sthis->pimpl_->bootstrapCbTest_)
+                    sthis->pimpl_->bootstrapCbTest_(sthis->id(), BootstrapStatus::SUCCESS);
+#endif
+                return;
+            }
+            // Fallback
+            auto acc = sthis->pimpl_->account_.lock();
+            if (!acc)
+                return;
+            auto members = sthis->getMembers(false, false);
+            std::shuffle(members.begin(), members.end(), acc->rand);
+            // TODO decide a formula
+            auto timeForBootstrap = std::min(static_cast<size_t>(8), members.size());
+            JAMI_DEBUG("{}[SwarmManager {}] Fallback in {} seconds",
+                       sthis->pimpl_->toString(),
+                       fmt::ptr(sthis->pimpl_->swarmManager_.get()),
+                       (20 - timeForBootstrap));
+            sthis->pimpl_->fallbackTimer_->expires_at(std::chrono::steady_clock::now() + 20s
+                                                      - std::chrono::seconds(timeForBootstrap));
+            sthis->pimpl_->fallbackTimer_->async_wait(std::bind(&Conversation::checkBootstrapMember,
+                                                                sthis,
+                                                                std::placeholders::_1,
+                                                                std::move(members)));
+        });
+    });
+    pimpl_->checkedMembers_.clear();
+    pimpl_->swarmManager_->setKnownNodes(devices);
+}
+
 std::vector<std::string>
 Conversation::refreshActiveCalls()
 {
@@ -1629,6 +1927,20 @@ Conversation::onLastDisplayedUpdated(
     pimpl_->lastDisplayedUpdatedCb_ = std::move(lastDisplayedUpdatedCb);
 }
 
+void
+Conversation::onNeedSocket(NeedSocketCb needSocket)
+{
+    pimpl_->swarmManager_->needSocketCb_ = [needSocket = std::move(needSocket),
+                                            this](const std::string& deviceId, ChannelCb&& cb) {
+        return needSocket(id(), deviceId, std::move(cb), "application/im-gitmessage-id");
+    };
+}
+void
+Conversation::addSwarmChannel(std::shared_ptr<ChannelSocket> channel)
+{
+    pimpl_->swarmManager_->addChannel(std::move(channel));
+}
+
 uint32_t
 Conversation::countInteractions(const std::string& toId,
                                 const std::string& fromId,
