@@ -20,8 +20,8 @@
 #pragma once
 
 #include "jamidht/conversationrepository.h"
-#include "jami/datatransfer_interface.h"
 #include "conversationrepository.h"
+#include "swarm/swarm_protocol.h"
 
 #include <json/json.h>
 #include <msgpack.hpp>
@@ -33,6 +33,8 @@
 #include <memory>
 #include <set>
 
+#include <asio.hpp>
+
 namespace jami {
 
 namespace ConversationMapKeys {
@@ -117,19 +119,45 @@ using OnLoadMessages
 using OnCommitCb = std::function<void(const std::string&)>;
 using OnDoneCb = std::function<void(bool, const std::string&)>;
 using OnMultiDoneCb = std::function<void(const std::vector<std::string>&)>;
+using DeviceId = dht::PkId;
+using GitSocketList = std::map<DeviceId, std::shared_ptr<ChannelSocket>>;
+using ChannelCb = std::function<bool(const std::shared_ptr<ChannelSocket>&)>;
+using NeedSocketCb
+    = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
 
 class Conversation : public std::enable_shared_from_this<Conversation>
 {
 public:
-    Conversation(const std::weak_ptr<JamiAccount>& account,
+    Conversation(const std::shared_ptr<JamiAccount>& account,
                  ConversationMode mode,
                  const std::string& otherMember = "");
-    Conversation(const std::weak_ptr<JamiAccount>& account, const std::string& conversationId = "");
-    Conversation(const std::weak_ptr<JamiAccount>& account,
+    Conversation(const std::shared_ptr<JamiAccount>& account,
+                 const std::string& conversationId = "");
+    Conversation(const std::shared_ptr<JamiAccount>& account,
                  const std::string& remoteDevice,
                  const std::string& conversationId);
     ~Conversation();
 
+    /**
+     * Print the state of the DRT linked to the conversation
+     */
+    void monitor();
+
+#ifdef LIBJAMI_TESTABLE
+    enum class BootstrapStatus { FAILED, FALLBACK, SUCCESS };
+    /**
+     * Used by the tests to get whenever the DRT is connected/disconnected
+     */
+    void onBootstrapStatus(const std::function<void(std::string, BootstrapStatus)>& cb);
+#endif
+
+    /**
+     * Bootstrap swarm manager to other peers
+     * @param onBootstraped     Callback called when connection is successfully established
+     * @param knownDevices      List of account's known devices
+     */
+    void bootstrap(std::function<void()> onBootstraped, const std::vector<DeviceId>& knownDevices);
+
     /**
      * Refresh active calls.
      * @note: If the host crash during a call, when initializing, we need to update
@@ -146,6 +174,21 @@ public:
     void onLastDisplayedUpdated(
         std::function<void(const std::string&, const std::string&)>&& lastDisplayedUpdatedCb);
 
+    /**
+     * Set the callback that will be called whenever a new socket will be needed
+     * @param cb
+     */
+    void onNeedSocket(NeedSocketCb cb);
+    /**
+     * Add swarm connection to the DRT
+     * @param channel       Related channel
+     */
+    void addSwarmChannel(std::shared_ptr<ChannelSocket> channel);
+
+    /**
+     * Get conversation's id
+     * @return conversation Id
+     */
     std::string id() const;
 
     // Member management
@@ -183,6 +226,24 @@ public:
                                                      MemberRole::LEFT,
                                                      MemberRole::BANNED}) const;
 
+    /**
+     * Get peers to sync with. This is mostly managed by the DRT
+     * @return some mobile nodes and all connected nodes
+     */
+    std::vector<NodeId> peersToSyncWith() const;
+    /**
+     * Check if we're at least connected to one node
+     * @return if the DRT is connected
+     */
+    bool isBootstraped() const;
+    /**
+     * Retrieve the uri from a deviceId
+     * @note used by swarm manager (peersToSyncWith)
+     * @param deviceId
+     * @return corresponding issuer
+     */
+    std::string uriFromDevice(const std::string& deviceId) const;
+
     /**
      * Join a conversation
      * @return commit id to send
@@ -442,6 +503,31 @@ public:
      */
     std::vector<std::map<std::string, std::string>> currentCalls() const;
 
+    /**
+     * Git operations will need a ChannelSocket for cloning/fetching commits
+     * Because libgit2 is a C library, we store the pointer in the corresponding conversation
+     * and the GitTransport will inject to libgit2 whenever needed
+     */
+    std::shared_ptr<ChannelSocket> gitSocket(const DeviceId& deviceId) const;
+    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<ChannelSocket>& socket);
+    void removeGitSocket(const DeviceId& deviceId);
+
+    /**
+     * Stop SwarmManager, bootstrap and gitSockets
+     */
+    void shutdownConnections();
+    /**
+     * Used to avoid multiple connections, we just check if we got a swarm channel with a specific
+     * device
+     * @param deviceId
+     */
+    bool hasSwarmChannel(const std::string& deviceId);
+
+    /**
+     * If we change from one network to one another, we will need to update the state of the connections
+     */
+    void connectivityChanged();
+
 private:
     std::shared_ptr<Conversation> shared()
     {
@@ -460,6 +546,15 @@ private:
         return std::static_pointer_cast<Conversation const>(shared_from_this());
     }
 
+    // Private because of weak()
+    /**
+     * Used by bootstrap() to launch the fallback
+     * @param ec
+     * @param members       Members to try to connect
+     */
+    void checkBootstrapMember(const asio::error_code& ec,
+                              std::vector<std::map<std::string, std::string>> members);
+
     class Impl;
     std::unique_ptr<Impl> pimpl_;
 };
