@@ -91,10 +91,6 @@ class SyncModule;
 struct TextMessageCtx;
 
 using SipConnectionKey = std::pair<std::string /* accountId */, DeviceId>;
-using GitSocketList = std::map<DeviceId,                               /* device Id */
-                               std::map<std::string,                   /* conversation */
-                                        std::shared_ptr<ChannelSocket> /* related socket */
-                                        >>;
 
 /**
  * @brief Ring Account is build on top of SIPAccountBase and uses DHT to handle call connectivity.
@@ -272,6 +268,9 @@ public:
     virtual bool getSrtpFallback() const override { return false; }
 
     bool setCertificateStatus(const std::string& cert_id, tls::TrustStore::PermissionStatus status);
+    bool setCertificateStatus(const std::shared_ptr<crypto::Certificate>& cert,
+                              tls::TrustStore::PermissionStatus status,
+                              bool local = true);
     std::vector<std::string> getCertificatesByStatus(tls::TrustStore::PermissionStatus status);
 
     bool findCertificate(const std::string& id);
@@ -315,11 +314,14 @@ public:
 
     void sendTrustRequest(const std::string& to, const std::vector<uint8_t>& payload);
     void sendMessage(const std::string& to,
+                     const std::string& deviceId,
                      const std::map<std::string, std::string>& payloads,
                      uint64_t id,
                      bool retryOnTimeout = true,
                      bool onlyConnected = false) override;
+
     uint64_t sendTextMessage(const std::string& to,
+                             const std::string& deviceId,
                              const std::map<std::string, std::string>& payloads,
                              uint64_t refreshToken = 0,
                              bool onlyConnected = false) override;
@@ -452,43 +454,6 @@ public:
      * ConnectionManager needs the account to exists
      */
     void shutdownConnections();
-    std::optional<std::weak_ptr<ChannelSocket>> gitSocket(const DeviceId& deviceId,
-                                                          const std::string& conversationId) const
-    {
-        auto deviceSockets = gitSocketList_.find(deviceId);
-        if (deviceSockets == gitSocketList_.end()) {
-            return std::nullopt;
-        }
-        auto socketIt = deviceSockets->second.find(conversationId);
-        if (socketIt == deviceSockets->second.end()) {
-            return std::nullopt;
-        }
-        return socketIt->second;
-    }
-    bool hasGitSocket(const DeviceId& deviceId, const std::string& conversationId) const
-    {
-        return gitSocket(deviceId, conversationId) != std::nullopt;
-    }
-
-    void addGitSocket(const DeviceId& deviceId,
-                      const std::string& conversationId,
-                      const std::shared_ptr<ChannelSocket>& socket)
-    {
-        auto& deviceSockets = gitSocketList_[deviceId];
-        deviceSockets[conversationId] = socket;
-    }
-
-    void removeGitSocket(const DeviceId& deviceId, const std::string& conversationId)
-    {
-        auto deviceSockets = gitSocketList_.find(deviceId);
-        if (deviceSockets == gitSocketList_.end()) {
-            return;
-        }
-        deviceSockets->second.erase(conversationId);
-        if (deviceSockets->second.empty()) {
-            gitSocketList_.erase(deviceSockets);
-        }
-    }
 
     std::string_view currentDeviceId() const;
 
@@ -501,7 +466,7 @@ public:
     bool handleMessage(const std::string& from,
                        const std::pair<std::string, std::string>& message) override;
 
-    void monitor() const;
+    void monitor();
 
     // File transfer
     void sendFile(const std::string& conversationId,
@@ -521,6 +486,7 @@ public:
                       size_t start = 0,
                       size_t end = 0,
                       const std::string& sha3Sum = "",
+                      uint64_t lastWriteTime = 0,
                       std::function<void()> onFinished = {});
 
     void askForFileChannel(const std::string& conversationId,
@@ -551,14 +517,18 @@ public:
      * @param sha3Sum       SHA3 hash of the profile
      */
     // Note: when swarm will be merged, this can be moved in transferManager
-    bool needToSendProfile(const std::string& peerUri, const std::string& deviceId, const std::string& sha3Sum);
+    bool needToSendProfile(const std::string& peerUri,
+                           const std::string& deviceId,
+                           const std::string& sha3Sum);
     /**
      * Send Profile via cached SIP connection
      * @param convId        Conversation's identifier (can be empty for self profile on sync)
      * @param peerUri       Uri that will receive the profile
      * @param deviceId      Device that will receive the profile
      */
-    void sendProfile(const std::string& convId, const std::string& peerUri, const std::string& deviceId);
+    void sendProfile(const std::string& convId,
+                     const std::string& peerUri,
+                     const std::string& deviceId);
     /**
      * Send profile via cached SIP connection
      * @param peerUri       Uri that will receive the profile
@@ -611,6 +581,28 @@ public:
      */
     void handleIncomingConversationCall(const std::string& callId, const std::string& destination);
 
+    /**
+     * The DRT component is composed on some special nodes, that are usually present but not
+     * connected. This kind of node corresponds to devices with push notifications & proxy and are
+     * stored in the mobile nodes
+     */
+    bool isMobile() const
+    {
+        return config().proxyEnabled and not config().deviceKey.empty();
+    }
+
+#ifdef LIBJAMI_TESTABLE
+    std::map<Uri::Scheme, std::unique_ptr<ChannelHandlerInterface>>& channelHandlers()
+    {
+        return channelHandlers_;
+    };
+#endif
+
+    tls::CertificateStore& certStore() const
+    {
+        return *certStore_;
+    }
+
 private:
     NON_COPYABLE(JamiAccount);
 
@@ -746,8 +738,7 @@ private:
     mutable std::mutex dhtValuesMtx_;
     bool dhtPublicInCalls_ {true};
 
-    std::string bootstrapListUrl_;
-
+    std::atomic_int syncCnt_ {0};
     /**
      * DHT port preference
      */
@@ -785,7 +776,6 @@ private:
 
     mutable std::mutex connManagerMtx_ {};
     std::unique_ptr<ConnectionManager> connectionManager_;
-    GitSocketList gitSocketList_ {};
 
     std::mutex discoveryMapMtx_;
     std::shared_ptr<dht::PeerDiscovery> peerDiscovery_;
@@ -909,6 +899,8 @@ private:
     std::unique_ptr<SyncModule> syncModule_;
 
     void initConnectionManager();
+
+    std::unique_ptr<tls::CertificateStore> certStore_;
 };
 
 static inline std::ostream&
