@@ -37,6 +37,7 @@
 #include "audio/audiolayer.h"
 #include "scheduled_executor.h"
 #include "gittransport.h"
+#include "connectivity/security/certstore.h"
 
 #include <algorithm>
 #include <atomic>
@@ -118,11 +119,13 @@ public:
     static bool isIOSExtension;
 #endif
 
+    static bool syncOnRegister;
+
     /**
      * Initialisation of thread (sound) and map.
      * Init a new VoIPLink, audio codec and audio driver
      */
-    void init(const std::string& config_file);
+    void init(const std::string& config_file, libjami::InitFlag flags);
 
     /*
      * Terminate all threads and exit DBus loop
@@ -710,9 +713,9 @@ public:
      * @return std::shared_ptr<Account> Shared pointer on an Account instance or nullptr if not found
      */
     template<class T = Account>
-    std::shared_ptr<T> getAccount(const std::string& accountID) const
+    inline std::shared_ptr<T> getAccount(std::string_view accountId) const
     {
-        return accountFactory.getAccount<T>(accountID);
+        return accountFactory.getAccount<T>(accountId);
     }
 
     /**
@@ -818,11 +821,12 @@ public:
      * @param videoStream the the VideoFrameActiveWriter to which the sinks should be attached
      * @param sinksMap A map between sink ids and the respective shared pointer.
      */
-    void createSinkClients(const std::string& callId,
-                           const ConfInfo& infos,
-                           const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
-                           std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
-                           const std::string& accountId = "");
+    void createSinkClients(
+        const std::string& callId,
+        const ConfInfo& infos,
+        const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
+        std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
+        const std::string& accountId = "");
 
     /**
      * Return an existing SinkClient instance as a shared_ptr associated to the given identifier.
@@ -839,7 +843,7 @@ public:
     AccountFactory accountFactory;
 
     std::vector<libjami::Message> getLastMessages(const std::string& accountID,
-                                                const uint64_t& base_timestamp);
+                                                  const uint64_t& base_timestamp);
 
     SIPVoIPLink& sipVoIPLink() const;
 #ifdef ENABLE_PLUGIN
@@ -852,9 +856,9 @@ public:
      * @param conversationId    Related conversation
      * @return std::optional<std::weak_ptr<ChannelSocket>> the related socket
      */
-    std::optional<std::weak_ptr<ChannelSocket>> gitSocket(const std::string& accountId,
-                                                          const std::string& deviceId,
-                                                          const std::string& conversationId);
+    std::shared_ptr<ChannelSocket> gitSocket(const std::string_view accountId,
+                                             const std::string_view deviceId,
+                                             const std::string_view conversationId);
 
     void setDefaultModerator(const std::string& accountID, const std::string& peerURI, bool state);
     std::vector<std::string> getDefaultModerators(const std::string& accountID);
@@ -866,6 +870,8 @@ public:
     void insertGitTransport(git_smart_subtransport* tr, std::unique_ptr<P2PSubTransport>&& sub);
     void eraseGitTransport(git_smart_subtransport* tr);
 
+    tls::CertificateStore& certStore(const std::string& accountId) const;
+
 private:
     Manager();
     ~Manager();
