@@ -71,8 +71,13 @@ struct MediaRecorder::StreamObserver : public Observer<std::shared_ptr<MediaFram
 
     ~StreamObserver()
     {
-        for (auto& obs : observablesFrames_) {
-            obs->detach(this);
+        while (observablesFrames_.size() > 0) {
+            auto obs = observablesFrames_.begin();
+            (*obs)->detach(this);
+            // it should be erased from observablesFrames_ in detach. If it does not happens erase frame to avoid infinite loop.
+            auto it = observablesFrames_.find(*obs);
+            if (it != observablesFrames_.end())
+                observablesFrames_.erase(it);
         }
     };
 
@@ -361,7 +366,7 @@ MediaRecorder::onFrame(const std::string& name, const std::shared_ptr<MediaFrame
         }
     } else if (audioFilter_ && outputAudioFilter_) {
 #endif // ENABLE_VIDEO
-        std::lock_guard<std::mutex> lk(mutexFilterAudio_);
+        std::lock_guard<std::mutex> lkA(mutexFilterAudio_);
         audioFilter_->feedInput(clone->pointer(), name);
         auto audioFilterOutput = audioFilter_->readOutput();
         if (audioFilterOutput) {
@@ -555,7 +560,7 @@ std::string
 MediaRecorder::buildVideoFilter(const std::vector<MediaStream>& peers,
                                 const MediaStream& local) const
 {
-    std::stringstream v;
+    std::ostringstream v;
 
     switch (peers.size()) {
     case 0:
@@ -677,7 +682,7 @@ MediaRecorder::buildAudioFilter(const std::vector<MediaStream>& peers,
                                 const MediaStream& local) const
 {
     std::string baseFilter = "aresample=osr=48000:ochl=stereo:osf=s16";
-    std::stringstream a;
+    std::ostringstream a;
 
     switch (peers.size()) {
     case 0:
