@@ -87,7 +87,8 @@ Q_SIGNALS:
     // Send report failure to QML to make it show the right UI state .
     void reportFailure();
     void accountCreationFailed();
-    void accountAdded(QString accountId, int index);
+    void accountAdded(const QString& accountId, int index);
+    void accountRemoved(const QString& accountId);
     void accountConfigFinalized();
 
 private:
