@@ -32,8 +32,8 @@
 #include <QTimer>
 #include <QJsonObject>
 
+#include <api/callmodel.h>
 #include <api/callparticipantsmodel.h>
-#include <api/devicemodel.h>
 
 #include <media_const.h>
 
@@ -47,15 +47,11 @@ CallAdapter::CallAdapter(SystemTray* systemTray, LRCInstance* instance, QObject*
     timer = new QTimer(this);
     connect(timer, &QTimer::timeout, this, &CallAdapter::updateAdvancedInformation);
 
-    participantsModel_.reset(new CallParticipantsModel(lrcInstance_, this));
-    QML_REGISTERSINGLETONTYPE_POBJECT(NS_MODELS, participantsModel_.get(), "CallParticipantsModel");
-
     overlayModel_.reset(new CallOverlayModel(lrcInstance_, this));
     QML_REGISTERSINGLETONTYPE_POBJECT(NS_MODELS, overlayModel_.get(), "CallOverlayModel");
 
     accountId_ = lrcInstance_->get_currentAccountId();
-    if (!accountId_.isEmpty())
-        connectCallModel(accountId_);
+    connectCallModel(accountId_);
 
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::showIncomingCallView,
@@ -76,6 +72,7 @@ CallAdapter::CallAdapter(SystemTray* systemTray, LRCInstance* instance, QObject*
     // notification responses (gnu/linux currently)
     connect(systemTray_,
             &SystemTray::answerCallActivated,
+            this,
             [this](const QString& accountId, const QString& convUid) {
                 acceptACall(accountId, convUid);
                 Q_EMIT lrcInstance_->notificationClicked();
@@ -85,6 +82,7 @@ CallAdapter::CallAdapter(SystemTray* systemTray, LRCInstance* instance, QObject*
             });
     connect(systemTray_,
             &SystemTray::declineCallActivated,
+            this,
             [this](const QString& accountId, const QString& convUid) {
                 hangUpACall(accountId, convUid);
             });
@@ -138,10 +136,10 @@ CallAdapter::onCallStatusChanged(const QString& accountId, const QString& callId
     // handle notifications
     if (call.status == lrc::api::call::Status::IN_PROGRESS) {
         // Call answered and in progress; close the notification
-        systemTray_->hideNotification(QString("%1;%2").arg(accountId).arg(convInfo.uid));
+        systemTray_->hideNotification(QString("%1;%2").arg(accountId, convInfo.uid));
     } else if (call.status == lrc::api::call::Status::ENDED) {
         // Call ended; close the notification
-        if (systemTray_->hideNotification(QString("%1;%2").arg(accountId).arg(convInfo.uid))
+        if (systemTray_->hideNotification(QString("%1;%2").arg(accountId, convInfo.uid))
             && call.startTime.time_since_epoch().count() == 0) {
             // This was a missed call; show a missed call notification
             auto convAvatar = Utils::conversationAvatar(lrcInstance_,
@@ -150,11 +148,11 @@ CallAdapter::onCallStatusChanged(const QString& accountId, const QString& callId
                                                         accountId);
             auto& accInfo = lrcInstance_->getAccountInfo(accountId);
             auto from = accInfo.conversationModel->title(convInfo.uid);
-            auto notifId = QString("%1;%2").arg(accountId).arg(convInfo.uid);
+            auto notifId = QString("%1;%2").arg(accountId, convInfo.uid);
             systemTray_->showNotification(notifId,
                                           tr("Missed call"),
                                           tr("Missed call with %1").arg(from),
-                                          NotificationType::CHAT,
+                                          SystemTray::NotificationType::CHAT,
                                           Utils::QImageToByteArray(convAvatar));
         }
     }
@@ -164,69 +162,6 @@ CallAdapter::onCallStatusChanged(const QString& accountId, const QString& callId
 #endif
 }
 
-void
-CallAdapter::onParticipantAdded(const QString& callId, int index)
-{
-    auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId_);
-    auto& callModel = accInfo.callModel;
-    try {
-        if (lrcInstance_->get_selectedConvUid().isEmpty())
-            return;
-
-        const auto& currentConvInfo = accInfo.conversationModel.get()->getConversationForUid(
-            lrcInstance_->get_selectedConvUid());
-        if (callId != currentConvInfo->get().callId && callId != currentConvInfo->get().confId) {
-            qDebug() << "trying to update not current conf";
-            return;
-        }
-        auto infos = getConferencesInfos();
-        if (index < infos.size())
-            participantsModel_->addParticipant(index, infos[index]);
-    } catch (...) {
-    }
-}
-
-void
-CallAdapter::onParticipantRemoved(const QString& callId, int index)
-{
-    auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId_);
-    auto& callModel = accInfo.callModel;
-    try {
-        if (lrcInstance_->get_selectedConvUid().isEmpty())
-            return;
-
-        const auto& currentConvInfo = accInfo.conversationModel.get()->getConversationForUid(
-            lrcInstance_->get_selectedConvUid());
-        if (callId != currentConvInfo->get().callId && callId != currentConvInfo->get().confId) {
-            qDebug() << "trying to update not current conf";
-            return;
-        }
-        participantsModel_->removeParticipant(index);
-    } catch (...) {
-    }
-}
-
-void
-CallAdapter::onParticipantUpdated(const QString& callId, int index)
-{
-    auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId_);
-    auto& callModel = accInfo.callModel;
-    try {
-        if (lrcInstance_->get_selectedConvUid().isEmpty())
-            return;
-        const auto& currentConvInfo = accInfo.conversationModel.get()->getConversationForUid(
-            lrcInstance_->get_selectedConvUid());
-        if (callId != currentConvInfo->get().callId && callId != currentConvInfo->get().confId) {
-            qDebug() << "trying to update not current conf";
-            return;
-        }
-        auto infos = getConferencesInfos();
-        if (index < infos.size())
-            participantsModel_->updateParticipant(index, infos[index]);
-    } catch (...) {
-    }
-}
-
 void
 CallAdapter::onCallStarted(const QString& callId)
 {
@@ -336,30 +271,6 @@ CallAdapter::onCallStatusChanged(const QString& callId, int code)
     }
 }
 
-void
-CallAdapter::onCallInfosChanged(const QString& accountId, const QString& callId)
-{
-    auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId);
-    auto& callModel = accInfo.callModel;
-
-    try {
-        const auto call = callModel->getCall(callId);
-        /*
-         * Change status label text.
-         */
-        const auto& convInfo = lrcInstance_->getConversationFromCallId(callId);
-        if (!convInfo.uid.isEmpty()) {
-            if (!convInfo.confId.isEmpty() && callId != convInfo.confId) {
-                // In this case the conv has a confId, ignore subcalls changes.
-                return;
-            }
-            Q_EMIT callInfosChanged(call.isAudioOnly, accountId, convInfo.uid);
-            participantsModel_->setConferenceLayout(static_cast<int>(call.layout), callId);
-        }
-    } catch (...) {
-    }
-}
-
 void
 CallAdapter::onCallAddedToConference(const QString& callId, const QString& confId)
 {
@@ -525,73 +436,6 @@ CallAdapter::updateCall(const QString& convUid, const QString& accountId, bool f
             }
         }
     }
-
-    participantsModel_->setParticipants(call->id, getConferencesInfos());
-    participantsModel_->setConferenceLayout(static_cast<int>(call->layout), call->id);
-}
-
-void
-CallAdapter::fillParticipantData(QJsonObject& participant) const
-{
-    // TODO: getCurrentDeviceId should be part of CurrentAccount, and Current<thing>
-    //       should be read accessible through LRCInstance ??
-    auto getCurrentDeviceId = [](const account::Info& accInfo) -> QString {
-        const auto& deviceList = accInfo.deviceModel->getAllDevices();
-        auto devIt = std::find_if(std::cbegin(deviceList),
-                                  std::cend(deviceList),
-                                  [](const Device& dev) { return dev.isCurrent; });
-        return devIt != deviceList.cend() ? devIt->id : QString();
-    };
-
-    auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId_);
-    using namespace lrc::api::ParticipantsInfosStrings;
-
-    // If both the URI and the device Id match, we set the "is local" flag
-    // used to filter out the participant.
-    // TODO:
-    //  - This filter should always be applied, and any local streams should render
-    //    using local sinks. Local non-preview participants should have proxy participant
-    //    items replaced into this model using their local sink Ids.
-    //  - The app setting should remain and be used to control whether or not the preview
-    //    sink partipcant is rendered.
-    auto uri = participant[URI].toString();
-    participant[ISLOCAL] = false;
-    if (uri == accInfo.profileInfo.uri && participant[DEVICE] == getCurrentDeviceId(accInfo)) {
-        participant[BESTNAME] = tr("Me");
-        participant[ISLOCAL] = true;
-    } else {
-        try {
-            participant[BESTNAME] = accInfo.contactModel->bestNameForContact(uri);
-        } catch (...) {
-        }
-    }
-}
-
-QVariantList
-CallAdapter::getConferencesInfos() const
-{
-    QVariantList map;
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
-    if (convInfo.uid.isEmpty())
-        return map;
-    auto callId = convInfo.confId.isEmpty() ? convInfo.callId : convInfo.confId;
-    if (!callId.isEmpty()) {
-        try {
-            auto& participantsModel = lrcInstance_->accountModel()
-                                          .getAccountInfo(accountId_)
-                                          .callModel.get()
-                                          ->getParticipantsInfos(callId);
-            for (int index = 0; index < participantsModel.getParticipants().size(); index++) {
-                auto participant = participantsModel.toQJsonObject(index);
-                fillParticipantData(participant);
-                map.push_back(QVariant(participant));
-            }
-            return map;
-        } catch (...) {
-        }
-    }
-    return map;
 }
 
 void
@@ -607,11 +451,11 @@ CallAdapter::showNotification(const QString& accountId, const QString& convUid)
 
 #ifdef Q_OS_LINUX
     auto convAvatar = Utils::conversationAvatar(lrcInstance_, convUid, QSize(50, 50), accountId);
-    auto notifId = QString("%1;%2").arg(accountId).arg(convUid);
+    auto notifId = QString("%1;%2").arg(accountId, convUid);
     systemTray_->showNotification(notifId,
                                   tr("Incoming call"),
                                   tr("%1 is calling you").arg(title),
-                                  NotificationType::CALL,
+                                  SystemTray::NotificationType::CALL,
                                   Utils::QImageToByteArray(convAvatar));
 #else
     auto onClicked = [this, accountId, convUid]() {
@@ -628,26 +472,10 @@ CallAdapter::showNotification(const QString& accountId, const QString& convUid)
 void
 CallAdapter::connectCallModel(const QString& accountId)
 {
+    if (accountId.isEmpty())
+        return;
+
     auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId);
-
-    connect(accInfo.callModel.get(),
-            &CallModel::participantAdded,
-            this,
-            &CallAdapter::onParticipantAdded,
-            Qt::UniqueConnection);
-
-    connect(accInfo.callModel.get(),
-            &CallModel::participantRemoved,
-            this,
-            &CallAdapter::onParticipantRemoved,
-            Qt::UniqueConnection);
-
-    connect(accInfo.callModel.get(),
-            &CallModel::participantUpdated,
-            this,
-            &CallAdapter::onParticipantUpdated,
-            Qt::UniqueConnection);
-
     connect(accInfo.callModel.get(),
             &CallModel::callStarted,
             this,
@@ -671,11 +499,6 @@ CallAdapter::connectCallModel(const QString& accountId)
             this,
             &CallAdapter::onCallAddedToConference,
             Qt::UniqueConnection);
-
-    connect(accInfo.callModel.get(),
-            &CallModel::callInfosChanged,
-            this,
-            QOverload<const QString&, const QString&>::of(&CallAdapter::onCallInfosChanged));
 }
 
 void
@@ -719,24 +542,19 @@ CallAdapter::setActiveStream(const QString& uri, const QString& deviceId, const
         confId = convInfo.callId;
     try {
         const auto call = callModel->getCall(confId);
-        auto participants = getConferencesInfos();
-        std::vector<QJsonObject> activeParticipants = {};
+        auto& participantsModel = callModel->getParticipantsInfos(call.id);
+        auto participants = participantsModel.getParticipants();
+        decltype(participants) activeParticipants = {};
         bool removeActive = false;
-        for (auto part : participants) {
-            auto participant = part.toJsonObject();
-
-            auto puri = participant[lrc::api::ParticipantsInfosStrings::URI].toString();
-            auto pdeviceId = participant[lrc::api::ParticipantsInfosStrings::DEVICE].toString();
-            auto pstreamId = participant[lrc::api::ParticipantsInfosStrings::STREAMID].toString();
-
-            auto isParticipant = puri == uri && pdeviceId == deviceId && pstreamId == streamId;
-            auto active = participant[lrc::api::ParticipantsInfosStrings::ACTIVE].toBool();
-            if (active && !isParticipant)
-                activeParticipants.push_back(participant);
+        for (const auto& part : participants) {
+            auto isParticipant = part.uri == uri && part.device == deviceId
+                                 && part.sinkId == streamId;
+            if (part.active && !isParticipant)
+                activeParticipants.push_back(part);
 
             if (isParticipant) {
                 // Else, continue.
-                if (!active) {
+                if (!part.active) {
                     callModel->setActiveStream(confId, uri, deviceId, streamId, true);
                     callModel->setConferenceLayout(confId, lrc::api::call::Layout::ONE_WITH_SMALL);
                 } else if (call.layout == lrc::api::call::Layout::ONE_WITH_SMALL) {
@@ -747,12 +565,8 @@ CallAdapter::setActiveStream(const QString& uri, const QString& deviceId, const
         }
         if (removeActive) {
             // If in Big, we can remove other actives
-            for (const auto& p : activeParticipants) {
-                auto puri = p[lrc::api::ParticipantsInfosStrings::URI].toString();
-                auto deviceId = p[lrc::api::ParticipantsInfosStrings::DEVICE].toString();
-                auto streamId = p[lrc::api::ParticipantsInfosStrings::STREAMID].toString();
-                callModel->setActiveStream(confId, puri, deviceId, streamId, false);
-            }
+            for (const auto& part : activeParticipants)
+                callModel->setActiveStream(confId, part.uri, part.device, part.sinkId, false);
         }
     } catch (...) {
     }
@@ -770,31 +584,24 @@ CallAdapter::minimizeParticipant(const QString& uri)
         confId = convInfo.callId;
     try {
         const auto call = callModel->getCall(confId);
-        auto participants = getConferencesInfos();
+        auto& participantsModel = callModel->getParticipantsInfos(call.id);
+        auto participants = participantsModel.getParticipants();
         auto activeParticipants = 0;
         for (auto& part : participants) {
-            auto participant = part.toJsonObject();
-            if (participant[lrc::api::ParticipantsInfosStrings::ACTIVE].toBool()) {
+            if (part.active) {
                 activeParticipants += 1;
-                if (participant[lrc::api::ParticipantsInfosStrings::URI].toString() == uri
-                    && call.layout == lrc::api::call::Layout::ONE_WITH_SMALL) {
-                    auto deviceId = participant[lrc::api::ParticipantsInfosStrings::DEVICE]
-                                        .toString();
-                    auto streamId = participant[lrc::api::ParticipantsInfosStrings::STREAMID]
-                                        .toString();
-                    callModel->setActiveStream(confId, uri, deviceId, streamId, false);
+                if (part.uri == uri && call.layout == lrc::api::call::Layout::ONE_WITH_SMALL) {
+                    callModel->setActiveStream(confId, part.uri, part.device, part.sinkId, false);
                 }
             }
         }
         if (activeParticipants == 1) {
             // only one active left, we can change the layout.
-            if (call.layout == lrc::api::call::Layout::ONE) {
+            if (call.layout == lrc::api::call::Layout::ONE)
                 callModel->setConferenceLayout(confId, lrc::api::call::Layout::ONE_WITH_SMALL);
-            } else {
+            else
                 callModel->setConferenceLayout(confId, lrc::api::call::Layout::GRID);
-            }
         }
-
     } catch (...) {
     }
 }
@@ -882,23 +689,6 @@ CallAdapter::participantIsHost(const QString& uri) const
     return true;
 }
 
-bool
-CallAdapter::isModerator(const QString& uri) const
-{
-    auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
-    const auto& convInfo = lrcInstance_->getConversationFromConvUid(
-        lrcInstance_->get_selectedConvUid());
-    auto confId = convInfo.confId;
-
-    if (confId.isEmpty())
-        confId = convInfo.callId;
-    try {
-        return callModel->isModerator(confId, uri);
-    } catch (...) {
-    }
-    return false;
-}
-
 bool
 CallAdapter::isHandRaised(const QString& uri) const
 {
@@ -1152,21 +942,21 @@ CallAdapter::updateAdvancedInformation()
 bool
 CallAdapter::takeScreenshot(const QImage& image, const QString& path)
 {
-    QString name = QString("%1 %2")
-                       .arg(tr("Screenshot"))
+    QString name = QString("%1 %2").arg(tr("Screenshot"),
 #ifdef WIN32
-                       .arg(QDateTime::currentDateTime().toString("yyyy-MM-dd HHmmss"));
+                                        QDateTime::currentDateTime().toString("yyyy-MM-dd HHmmss")
 #else
-                       .arg(QDateTime::currentDateTime().toString(Qt::ISODate));
+                                        QDateTime::currentDateTime().toString(Qt::ISODate)
 #endif
+    );
 
     bool fileAlreadyExists = true;
     int nb = 0;
-    QString filePath = QString("%1%2.png").arg(path).arg(name);
+    QString filePath = QString("%1%2.png").arg(path, name);
     while (fileAlreadyExists) {
-        filePath = QString("%1%2.png").arg(path).arg(name);
+        filePath = QString("%1%2.png").arg(path, name);
         if (nb)
-            filePath = QString("%1(%2).png").arg(filePath).arg(QString::number(nb));
+            filePath = QString("%1(%2).png").arg(filePath, QString::number(nb));
         QFileInfo check_file(filePath);
         fileAlreadyExists = check_file.exists() && check_file.isFile();
         nb++;
