@@ -78,22 +78,33 @@ ScreenInfo::setCurrentFocusWindow(QWindow* window)
         currentFocusWindow_ = window;
         set_devicePixelRatio(currentFocusWindow_->screen()->devicePixelRatio());
 
-        disconnect(devicePixelRatioConnection_);
-        disconnect(currentFocusWindowScreenConnection_);
-
-        currentFocusWindowScreenConnection_
-            = connect(currentFocusWindow_, &QWindow::screenChanged, [this] {
-                  currentFocusWindowScreen_ = currentFocusWindow_->screen();
-                  set_devicePixelRatio(currentFocusWindowScreen_->devicePixelRatio());
-
-                  devicePixelRatioConnection_ = connect(
-                      currentFocusWindowScreen_, &QScreen::physicalDotsPerInchChanged, [this] {
-                          set_devicePixelRatio(currentFocusWindowScreen_->devicePixelRatio());
-                      });
-              });
+        QObject::connect(currentFocusWindow_,
+                         &QWindow::screenChanged,
+                         this,
+                         &ScreenInfo::onScreenChanged,
+                         Qt::UniqueConnection);
     }
 }
 
+void
+ScreenInfo::onScreenChanged()
+{
+    currentFocusWindowScreen_ = currentFocusWindow_->screen();
+    set_devicePixelRatio(currentFocusWindowScreen_->devicePixelRatio());
+
+    QObject::connect(currentFocusWindowScreen_,
+                     &QScreen::physicalDotsPerInchChanged,
+                     this,
+                     &ScreenInfo::onPhysicalDotsPerInchChanged,
+                     Qt::UniqueConnection);
+}
+
+void
+ScreenInfo::onPhysicalDotsPerInchChanged()
+{
+    set_devicePixelRatio(currentFocusWindowScreen_->devicePixelRatio());
+}
+
 MainApplication::MainApplication(int& argc, char** argv)
     : QApplication(argc, argv)
 {
@@ -122,7 +133,7 @@ MainApplication::init()
     connectivityMonitor_.reset(new ConnectivityMonitor(this));
     settingsManager_.reset(new AppSettingsManager(this));
     systemTray_.reset(new SystemTray(settingsManager_.get(), this));
-    previewEngine_.reset(new PreviewEngine(this));
+    previewEngine_.reset(new PreviewEngine(connectivityMonitor_.get(), this));
 
     QObject::connect(settingsManager_.get(),
                      &AppSettingsManager::retranslate,
@@ -166,13 +177,6 @@ MainApplication::init()
         screenInfo_.setCurrentFocusWindow(this->focusWindow());
     });
 
-    QObject::connect(
-        lrcInstance_.get(),
-        &LRCInstance::quitEngineRequested,
-        this,
-        [this] { engine_->quit(); },
-        Qt::DirectConnection);
-
     auto downloadPath = settingsManager_->getValue(Settings::Key::DownloadPath);
     auto screenshotPath = settingsManager_->getValue(Settings::Key::ScreenshotPath);
     auto allowTransferFromTrusted = settingsManager_->getValue(Settings::Key::AutoAcceptFiles)
