@@ -48,6 +48,7 @@ UtilsAdapter::UtilsAdapter(AppSettingsManager* settingsManager,
     if (lrcInstance_->avModel().getRecordPath().isEmpty()) {
         lrcInstance_->avModel().setRecordPath(getDefaultRecordPath());
     }
+    set_isRTL(isRTL());
 }
 
 QVariant
@@ -80,6 +81,7 @@ UtilsAdapter::setAppValue(const Settings::Key key, const QVariant& value)
     if (key == Settings::Key::LANG) {
         settingsManager_->loadTranslations();
         Q_EMIT changeLanguage();
+        set_isRTL(isRTL());
     } else if (key == Settings::Key::BaseZoom)
         Q_EMIT changeFontSize();
     else if (key == Settings::Key::EnableExperimentalSwarm)
@@ -90,6 +92,18 @@ UtilsAdapter::setAppValue(const Settings::Key key, const QVariant& value)
         Q_EMIT appThemeChanged();
 }
 
+QVariant
+UtilsAdapter::getDefault(const Settings::Key key)
+{
+    return settingsManager_->getDefault(key);
+}
+
+void
+UtilsAdapter::setToDefault(const Settings::Key key)
+{
+    setAppValue(key, settingsManager_->getDefault(key));
+}
+
 const QString
 UtilsAdapter::getProjectCredits()
 {
@@ -118,15 +132,13 @@ const QString
 UtilsAdapter::getStyleSheet(const QString& name, const QString& source)
 {
     auto simplifiedCSS = source.simplified().replace("'", "\"");
-    QString s = QString::fromLatin1("(function() {"
-                                    "    var node = document.createElement('style');"
-                                    "    node.id = '%1';"
-                                    "    node.innerHTML = '%2';"
-                                    "    document.head.appendChild(node);"
-                                    "})()")
-                    .arg(name)
-                    .arg(simplifiedCSS);
-    return s;
+    static auto baseScript = QString::fromLatin1("(function() {"
+                                                 "    var node = document.createElement('style');"
+                                                 "    node.id = '%1';"
+                                                 "    node.innerHTML = '%2';"
+                                                 "    document.head.appendChild(node);"
+                                                 "})()");
+    return baseScript.arg(name, simplifiedCSS);
 }
 
 const QString
@@ -182,6 +194,27 @@ UtilsAdapter::getBestNameForUri(const QString& accountId, const QString& uri)
     return lrcInstance_->getAccountInfo(accountId).contactModel->bestNameForContact(uri);
 }
 
+QString
+UtilsAdapter::getBestIdForUri(const QString& accountId, const QString& uri)
+{
+    return lrcInstance_->getAccountInfo(accountId).contactModel->bestIdForContact(uri);
+}
+
+QString
+UtilsAdapter::getConvIdForUri(const QString& accountId, const QString& uri)
+{
+    try {
+        auto* convModel = lrcInstance_->getAccountInfo(accountId).conversationModel.get();
+        auto convInfo = convModel->getConversationForPeerUri(uri);
+        if (!convInfo)
+            return {};
+        return convInfo->get().uid;
+    } catch (const std::out_of_range& e) {
+        qDebug() << e.what();
+        return "";
+    }
+}
+
 const QString
 UtilsAdapter::getPeerUri(const QString& accountId, const QString& uid)
 {
@@ -219,16 +252,10 @@ UtilsAdapter::setConversationFilter(const QString& filter)
     lrcInstance_->getCurrentConversationModel()->setFilter(filter);
 }
 
-const QStringList
-UtilsAdapter::getCurrAccList()
-{
-    return lrcInstance_->accountModel().getAccountList();
-}
-
 int
 UtilsAdapter::getAccountListSize()
 {
-    return getCurrAccList().size();
+    return lrcInstance_->accountModel().getAccountList().size();
 }
 
 bool
@@ -286,20 +313,6 @@ UtilsAdapter::getCallStatusStr(int statusInt)
     return lrc::api::call::to_string(status);
 }
 
-// returns true if name is valid registered name
-bool
-UtilsAdapter::validateRegNameForm(const QString& regName)
-{
-    QRegularExpression regExp(" ");
-
-    if (regName.size() > 2 && !regName.contains(regExp)) {
-        return true;
-
-    } else {
-        return false;
-    }
-}
-
 QString
 UtilsAdapter::getStringUTF8(QString string)
 {
@@ -348,15 +361,14 @@ UtilsAdapter::toFileAbsolutepath(QString inputFileName)
 QString
 UtilsAdapter::getAbsPath(QString path)
 {
+    static auto fileSchemeRe = QRegularExpression("^file:\\/{2,3}");
     // Note: this function is used on urls returned from qml-FileDialogs which
     // contain 'file:///' for reasons we don't understand.
     // TODO: this logic can be refactored into the JamiFileDialog component.
 #ifdef Q_OS_WIN
-    return path.replace(QRegularExpression("^file:\\/{2,3}"), "").replace("\n", "").replace("\r", "");
+    return path.replace(fileSchemeRe, "").replace("\n", "").replace("\r", "");
 #else
-    return path.replace(QRegularExpression("^file:\\/{2,3}"), "/")
-        .replace("\n", "")
-        .replace("\r", "");
+    return path.replace(fileSchemeRe, "/").replace("\n", "").replace("\r", "");
 #endif
 }
 
@@ -367,6 +379,13 @@ UtilsAdapter::fileName(const QString& path)
     return fi.fileName();
 }
 
+QString
+UtilsAdapter::dirName(const QString& path)
+{
+    QDir dir(path);
+    return dir.dirName();
+}
+
 QString
 UtilsAdapter::getExt(const QString& path)
 {
@@ -472,6 +491,7 @@ UtilsAdapter::monitor(const bool& continuous)
         debugMessageReceivedConnection_
             = QObject::connect(&lrcInstance_->behaviorController(),
                                &lrc::api::BehaviorController::debugMessageReceived,
+                               this,
                                [this](const QString& data) {
                                    logList_.append(data);
                                    if (logList_.size() >= LOGSLIMIT) {
@@ -506,22 +526,22 @@ UtilsAdapter::supportedLang()
     QString appDir = qApp->applicationDirPath() + QDir::separator() + "share";
 #endif
     auto trDir = QDir(appDir + QDir::separator() + "jami" + QDir::separator() + "translations");
-    QStringList trFiles = trDir.entryList(QStringList() << "ring_client_windows_*.qm", QDir::Files);
+    QStringList trFiles = trDir.entryList(QStringList() << "jami_client_qt_*.qm", QDir::Files);
     QVariantMap result;
     result["SYSTEM"] = tr("System");
     // Get available locales
-    QRegExp regex("ring_client_windows_(.*).qm");
+    QRegExp regex("jami_client_qt_(.*).qm");
     QSet<QString> nativeNames;
     for (const auto& f : trFiles) {
-        auto match = regex.indexIn(f);
-        if (regex.capturedTexts().size() == 2) {
-            auto l = regex.capturedTexts()[1];
-            auto nativeName = QLocale(l).nativeLanguageName();
+        regex.indexIn(f);
+        auto captured = regex.capturedTexts();
+        if (captured.size() == 2) {
+            auto nativeName = QLocale(captured[1]).nativeLanguageName();
             if (nativeName.isEmpty()) // If a locale doesn't have any nativeLanguageName, ignore it.
                 continue;
             // Avoid to show potential duplicates.
             if (!nativeNames.contains(nativeName)) {
-                result[l] = nativeName;
+                result[captured[1]] = nativeName;
                 nativeNames.insert(nativeName);
             }
         }
@@ -774,3 +794,19 @@ UtilsAdapter::getVideoPlayer(const QString& resource, const QString& bgColor)
         {"html", htmlVideo.arg(resource, bgColor)},
     };
 }
+
+bool
+UtilsAdapter::isRTL()
+{
+    auto pref = getAppValue(Settings::Key::LANG).toString();
+    pref == "SYSTEM" ? QLocale::system().name() : pref;
+    return pref == "ar" || pref == "he" || pref == "fa" || pref == "ur";
+}
+
+bool
+UtilsAdapter::isSystemTrayIconVisible()
+{
+    if (!systemTray_)
+        return false;
+    return systemTray_->geometry() != QRect();
+}
